<?php
namespace Forgood\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Forgood.
* @since 1.0.0
**/
class Fgood_Blog extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'fgood-blog';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fgood Blog', 'forgood' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-box';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'forgood_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'forgood' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'forgood' ),
			]
		);

		$this->add_control(
			'blog-style',
			[
				'label' => __( 'Blog Style', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Blog Grid', 'forgood' ),
					'2' => __( 'Blog Grid Slider', 'forgood' ),
					'3' => __( 'Blog List', 'forgood' ),
				],
			]
		);

		$this->add_control(
			'blog-column',
			[
				'label' => __( 'Blog Column Style', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-4' => __( 'col-lg-4', 'forgood' ),
					'col-lg-6' => __( 'col-lg-6', 'forgood' ),
					'col-lg-3' => __( 'col-lg-3', 'forgood' ),
					'col-lg-12' => __( 'col-lg-12', 'forgood' ),
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'forgood' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'DSC',
				'options' => [
					'ASC' => __( 'ASC', 'forgood' ),
					'DSC' => __( 'DSC', 'forgood' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'forgood' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'forgood' ),
				'default'     => esc_html__('-1','forgood')
			]
		);

		$this->add_control(
			'post-offset',
			[
				'label'       => esc_html__( 'Post Offset', 'forgood' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Offset', 'forgood' ),
				'default'     => esc_html__('0','forgood')
			]
		);
		$this->end_controls_section();

		//blog grid style
		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'forgood' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		//total area style field
		$this->add_control (
			'details',
			[
				'label' => __( 'Details Space', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'details_space',
			[
				'label' => __( 'Details Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner .details' => 'padding: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}}.single-blog-inner .details' => 'padding: {{SIZE}}{{UNIT}};',
				],
			]
		);

		//date style field
		$this->add_control (
			'date_style',
			[
				'label' => __( 'Date Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'date_color',
			[
				'label' => __( 'Date Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner .details .date' => 'color: {{VALUE}};',
				],
			]
		);
		//title style field
		$this->add_control (
			'title_style',
			[
				'label' => __( 'Title Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner .details .title' => 'font-size: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}}.single-blog-inner .details .title' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'title_hover_color',
			[
				'label' => __( 'Title Hover Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner .details .title:hover a' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'title_bottom_space',
			[
				'label' => __( 'Title Bottom Spacing', 'forgood' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner .details .title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		//title style field
		$this->add_control (
			'slider_style',
			[
				'label' => __( 'Slider Style', 'forgood' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'slider_dots',
			[
				'label' => __( 'Slider Dots Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .blog-slider .owl-dots .owl-dot.active' => 'background: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$blog_column  = (isset($settings['blog-column']) ? $settings['blog-column'] : 'col-lg-4');?>


		<?php $blog_query = new \WP_Query(array('post_type'=> 'post', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'], 'offset' => $settings['post-offset'] ));

		if($settings['blog-style'] == 2){ ?>
			<div class="blog-slider owl-carousel">
				<?php if($blog_query->have_posts()) : 
					while($blog_query->have_posts()) : $blog_query->the_post(); ?>
		                <div class="item">
		                	<div class="single-blog-inner style-grid">
		                        <div class="thumb">
		                            <?php echo get_the_post_thumbnail( null, 'forgood-blog-thumbnail-1', array('class'=> 'img-responsive') ) ?>
		                        </div>
		                        <div class="details">
		                            <p class="date mt-0"><?php echo get_the_date('M d Y') ?></p>
		                            <h5 class="title"><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
        							<p class="content"><?php print wp_trim_words( get_the_content(), 15, null ); ?></p>
		                        </div>
		                    </div>
		                </div>
					<?php endwhile;
					wp_reset_postdata();
				endif;	?>
			</div>
		<?php }elseif($settings['blog-style'] == 3){ 
			if($blog_query->have_posts()) : 
				while($blog_query->have_posts()) : $blog_query->the_post(); ?>
                    <div class="single-blog-inner style-list">
                    	<div class="row no-gutters">
                    		<div class="col-md-4">
                    			<div class="thumb-wrap">
                    				<?php $image_url = get_the_post_thumbnail_url(); ?>
		                        	<div class="thumb" style="background: url( <?php echo esc_url( $image_url ); ?> );"></div>
                    			</div>
                    		</div>
                    		<div class="col-md-8 align-self-center">
                    			<div class="details">
		                            <p class="date mt-0"><?php echo get_the_date('M d Y') ?></p>
		                            <h5 class="title"><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
	    							<p class="content"><?php print wp_trim_words( get_the_content(), 53, null ); ?></p>
		                        </div>
                    		</div>
                    	</div>
                    </div>
				<?php endwhile;
				wp_reset_postdata();
			endif;
		} else { ?>
			<div class="row justify-content-center">
				<?php if($blog_query->have_posts()) : 
					while($blog_query->have_posts()) : $blog_query->the_post(); ?>
						<div class="<?php echo $blog_column ?> col-md-6">
		                    <div class="single-blog-inner style-grid">
		                        <div class="thumb">
		                            <?php echo get_the_post_thumbnail( null, 'forgood-blog-thumbnail-1', array('class'=> 'img-responsive') ) ?>
		                        </div>
		                        <div class="details">
		                            <p class="date mt-0"><?php echo get_the_date('M d Y') ?></p>
		                            <h5 class="title"><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
        							<p class="content"><?php print wp_trim_words( get_the_content(), 15, null ); ?></p>
		                        </div>
		                    </div>
		                </div>
					<?php endwhile;
					wp_reset_postdata();
				endif; ?>
			</div>
		<?php } ?>
	<?php }
}